==> SPVM-0.989041.tar.gz: SPVM-0.989041/lib/SPVM/Immutable/FloatList.pm <==
package SPVM::Immutable::FloatList;

1;

=head1 Name

SPVM::Immutable::FloatList - Immutable float Array

=head1 Description

The Immutable::FloatList class has methods to manipulate an immutable float array.

=head1 Usage
  
  use Immutable::FloatList;
  
  # Create a float list
  my $list = Immutable::FloatList->new;
  my $list = Immutable::FloatList->new([(float)1, 2, 3]);
  
  # Create a float list with array length
  my $list = Immutable::FloatList->new_len(10);
  
  # Get list length
  my $length = $list->length;
  
  # Get value.
  my $element = $list->get(2);
  
  # Convert list to array.
  my $array = $list->to_array;
  
=head1 Fields

=head2 length

  has length : ro int;

Gets the C<length> field.

This field is the length of the elements of the list.

=head1 Class Methods

=head2 new

  static method new : Immutable::FloatList ($array : float[] = undef);

Create a new L<Immutable::FloatList|SPVM::Immutable::FloatList> object using L</"new_len">.

The passed length to L</"new_len"> is the length of the array. If the array is undef, the length is 0.

The elements of the array are copied to the elements of the the created array.

Examples:

  my $list = Immutable::FloatList->new;
  my $list = Immutable::FloatList->new([(float)1, 2, 3]);

=head2 new_len

  static method new_len : Immutable::FloatList ($length : int);

Creates a new L<Immutable::FloatList|SPVM::Immutable::FloatList> object with $length.

$length must be greater than or equal to 0. Otherwise an exception is thrown.

=head1 Instance Methods

=head2 get

  method get : float ($index : int);

Gets the element of the position of $index.

Exceptions:

$index must be greater than or equal to 0. Otherwise an exception is thrown.

$index must be less than the length of $list.

=head2 to_array

  method to_array : float[] ();

Converts the list to an array.

=head1 Copyright & License

Copyright (c) 2023 Yuki Kimoto

MIT License

==> SPVM-0.990092.tar.gz: SPVM-0.990092/lib/SPVM/Immutable/FloatList.pm <==
package SPVM::Immutable::FloatList;

1;

=head1 Name

SPVM::Immutable::FloatList - Immutable float Array

=head1 Description

The Immutable::FloatList class has methods to manipulate an immutable float array.

=head1 Usage
  
  use Immutable::FloatList;
  
  # Create a float list
  my $list = Immutable::FloatList->new;
  my $list = Immutable::FloatList->new([(float)1, 2, 3]);
  
  # Create a float list with array length
  my $list = Immutable::FloatList->new_len(10);
  
  # Get list length
  my $length = $list->length;
  
  # Get value.
  my $element = $list->get(2);
  
  # Convert list to array.
  my $array = $list->to_array;
  
=head1 Fields

=head2 length

  has length : ro int;

Gets the C<length> field.

This field is the length of the elements of the list.

=head1 Class Methods

=head2 new

C<static method new : L<Immutable::FloatList|SPVM::Immutable::FloatList> ($array : float[] = undef);>

Create a new L<Immutable::FloatList|SPVM::Immutable::FloatList> object using L</"new_len">.

The passed length to L</"new_len"> is the length of the array. If the array is undef, the length is 0.

The elements of the array are copied to the elements of the the created array.

Examples:

  my $list = Immutable::FloatList->new;
  my $list = Immutable::FloatList->new([(float)1, 2, 3]);

=head2 new_len

C<static method new_len : L<Immutable::FloatList|SPVM::Immutable::FloatList> ($length : int);>

Creates a new L<Immutable::FloatList|SPVM::Immutable::FloatList> object with $length.

$length must be greater than or equal to 0. Otherwise an exception is thrown.

=head1 Instance Methods

=head2 get

C<method get : float ($index : int);>

Gets the element of the position of $index.

Exceptions:

$index must be greater than or equal to 0. Otherwise an exception is thrown.

$index must be less than the length of $list.

=head2 to_array

C<method to_array : float[] ();>

Converts the list to an array.

=head1 Copyright & License

Copyright (c) 2023 Yuki Kimoto

MIT License
